<?php
/**
* Class ContentManager
*
* Class for managing the site content
*
* @copyright	CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author		Astalavista Development Team <thun@astalvista.ch>
* @access		public
* @module		contentManager
* @modulegroup	core
* @version		1.0.0
*/


class ContentManager
{
   /**
    * @var string
    * @desc page title
    */ 	
	var $pagetitle="";
	
   /**
    * @var string
    * @desc status message (error message)
    */ 		
	var $statusMessage = "";
	
   /**
    * @var string
    * @desc module id
    */ 		
	var $setModule = "";
	
   /**
    * @var string
    * @desc CMD
    */ 	
	var $setCmd = "";
	
   /**
    * @var array
    * @desc Array with the WYSIWYG module ids
    */ 	
	var $arrNoExpertmodes = array();
		
   /**
    * @var int
    * @desc Language id
    */ 	
	var $langId;

   /**
    * @var array
    * @desc array of all frontend groups ( name, id )
    */ 	
	var $arrAllFrontendGroups = array();
	
   /**
    * @var array
    * @desc array of all backend groups ( name, id )
    */ 	
	var $arrAllBackendGroups = array();	

	
   /**
    * @var array
    * @desc array of required modules
    * 1->core, 13->ids, 14->error, 15->home, 18->login
    *
    * @access private
    */ 	
	var $_requiredModules = array(1,13,14,15,18);	
	
	
	var $_navtable = array();
	
	var $_arrRedirectTargets = array('', '_blank', '_parent', '_self', '_top');
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */
    function ContentManager()
    {        
    	global $objDatabase, $objInit, $_CORELANG, $objTemplate;
    	
		$this->langId=$objInit->userFrontendLangId;
		
		$objTemplate->setVariable("CONTENT_NAVIGATION",
		                   "<a href='index.php?cmd=content&amp;act=new'>[".$_CORELANG['TXT_NEW_PAGE']."]</a>&nbsp;
		                    <a href='index.php?cmd=content'>[".$_CORELANG['TXT_CONTENT_MANAGER']."]</a>&nbsp;
		                    <a href='index.php?cmd=media&amp;path=/images/content/'>[".$_CORELANG['TXT_IMAGE_ADMINISTRATION']."]</a>");

		$objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."content");
	    $objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."content_navigation");
	    
   		// normally all modules are in source code mode
   		// Except the following modules : 15 Home, 13 Error, 14 IDS, 0 no module 
   		// Not in use anymore!    
        $this->arrNoExpertmodes = array(0,13,14,15);
        	
        $this->arrAllFrontendGroups = $this->_getAllGroups($groupType="frontend"); 
        $this->arrAllBackendGroups = $this->_getAllGroups($groupType="backend");     
    }
    
    /**
    * getPage
    *
    * calls the requested function
    *
    */
    function getPage()
    {
    	global $_CORELANG, $objTemplate, $objPerm;
    	
    	if(!isset($_GET['act'])){
    	    $_GET['act']="";	
    	}   	  	
    	    	
        switch ($_GET['act']) {
		case "deleteAll":
		    $objPerm->checkAccess(53, 'static');
		    $this->_deleteAll();
		    $this->contentOverview();
		    // header("Location: index.php?cmd=content");
		    break;
		    
		case "copyAll":
			$objPerm->checkAccess(53, 'static');
			$this->_copyAll();
			$this->showCopyPage();
			break;
			
		case "new":
		    $objPerm->checkAccess(5, 'static');
		    $this->showNewPage();
		    break;
		    
		case "edit":
		    $objPerm->checkAccess(35, 'static');
			$this->showEditPage();
		    break;
		
		case "update":
		    $objPerm->checkAccess(35, 'static');
		    $this->updatePage();
		    $this->showEditPage();
		    break;				   
		    
		case "changeprotection":	    
		    $this->changeProtection();			    
	        $this->contentOverview();
		    break;	
		    		
		case "changestatus":
		    $objPerm->checkAccess(35, 'static');		    
		    $this->changeStatus();
	        $this->contentOverview();
		    break;			
		
		case "add":
		    $objPerm->checkAccess(5, 'static');
		    $pageId = intval($this->addPage());
		    $this->showEditPage($pageId);
	        break;	
		
		case "delete":
		    $objPerm->checkAccess(26, 'static');
		    $this->deleteContent();
	        $this->contentOverview();
		    break;
		/*    
	    case "updatepermission":
	        $objPerm->checkAccess(36, 'static');		    
		    $this->_updateFrontendPermissions();
	        $this->contentOverview();
		    break;
		*/

		case "addrepository":
		    $objPerm->checkAccess(37, 'static');		    
		    $this->addToRepository();
	        $this->contentOverview();
		    break;
		    
		default:
		    $objPerm->checkAccess(6, 'static');
	        $this->contentOverview();
	        break;
		}
		
		$objTemplate->setVariable(array(
			'CONTENT_TITLE'				=> $this->pageTitle,
			'CONTENT_STATUS_MESSAGE'	=> $this->statusMessage
		));
    }
	
	/**
	* Show copy page
	*
	* @global	array $_CORELANG
	*/
	function showCopyPage()
	{
		global $_CORELANG, $objLanguage, $objTemplate;
		
		if (isset($_REQUEST['langOriginal']) && !empty($_REQUEST['langOriginal'])) {
			$this->contentOverview();
			unset($_REQUEST['langOriginal']);
		} else {						
			$objTemplate->addBlockfile('ADMIN_CONTENT', 'content_copy_all', 'content_copy_all.html');
			$this->pageTitle = $_CORELANG['TXT_COPY_CONTENT'];
			$objTemplate->setVariable(array(
				'TXT_COPY_CONTENT'	=> $_CORELANG['TXT_COPY_CONTENT'],
				'TXT_COPY'			=> $_CORELANG['TXT_COPY'],
				'TXT_COPY_CONTENT_OF_TO'	=> $_CORELANG['TXT_COPY_CONTENT_OF_TO'],
				'TXT_THIS_PROCEDURE_DELETES_ALL_EXISTING_ENTRIES_OF_THE_SELECTED_LANGUAGE' => $_CORELANG['TXT_THIS_PROCEDURE_DELETES_ALL_EXISTING_ENTRIES_OF_THE_SELECTED_LANGUAGE'],
				'TXT_WARNING'		=> $_CORELANG['TXT_WARNING'],
				'TXT_DO_YOU_WANT_TO_CONTINUE'	=> $_CORELANG['TXT_DO_YOU_WANT_TO_CONTINUE']
			));
					
			foreach ($objLanguage->getLanguageArray() as $key){
				if ($key['id'] == $this->langId) {
					$objTemplate->setVariable(array(
						'LANG_OLD_ID' => $this->langId,
						'LANG_OLD_NAME' => $key['name']
					));
				} else {
					$objTemplate->setVariable(array(
						'LANG_ID' => $key['id'],
						'LANG_NAME' => $key['name']
					));
					$objTemplate->parse('langList');
				}
			}
		}
	}
	
	/**
	* Copy page content
	*
	* @global	object	$objDatabase
	* @global	array	$_CORELANG
	*/
	function _copyAll()
	{
		global $objDatabase, $_CORELANG;

		if (isset($_POST['langOriginal']) && !empty($_POST['langOriginal'])) {
			$this->_deleteAll(intval($_POST['langNew']));
			$objResult = $objDatabase->Execute("SELECT catid,
								  parcat,
								  catname,
								  displayorder,
								  displaystatus,
								  username,
								  changelog,
								  cmd,
								  module,
								  startdate,
								  enddate,
								  themes_id
							 FROM ".DBPREFIX."content_navigation
							WHERE lang=".intval($_POST['langOriginal']));
			$arrQuery = array();
			$arrId = array();
			if ($objResult !== false) {
				while (!$objResult->EOF) {
					array_push($arrQuery, "INSERT INTO ".DBPREFIX."content_navigation (
														parcat, 
														catname, 
														displayorder, 
														displaystatus, 
														username, 
														changelog, 
														cmd, 
														lang,
														module,
														startdate,
														enddate,
														protected,  
														themes_id
														) VALUES (
														'".addslashes($objResult->fields["parcat"])."',  
														'".addslashes($objResult->fields["catname"])."',  
														'".addslashes($objResult->fields["displayorder"])."', 
														'".addslashes($objResult->fields["displaystatus"])."', 
														'".addslashes($objResult->fields["username"])."', 
														'".addslashes($objResult->fields["changelog"])."', 
														'".addslashes($objResult->fields['cmd'])."', 	
														".intval($_POST['langNew']).", 
														'".addslashes($objResult->fields["module"])."', 
														'".addslashes($objResult->fields["startdate"])."', 
														'".addslashes($objResult->fields["enddate"])."', 
														'0',
														'".intval($objResult->fields["themes_id"])."'
														)");
					array_push($arrId,array("old" => $objResult->fields["catid"]));
					$objResult->MoveNext();
				}
			}
			
			for ($i=0; $i<count($arrQuery); $i++) {
				$objDatabase->Execute($arrQuery[$i]);
				$arrId[$i]['new'] = $objDatabase->Insert_ID();
			}
			
			for ($i=0; $i<count($arrId); $i++) {
			    $objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation 
			                      SET parcat='".intval($arrId[$i]['new'])."'
			                    WHERE parcat='".intval($arrId[$i]['old'])."'
			                      AND lang='".intval($_POST['langNew'])."'
			                      AND parcat!=0");
			}
			
			unset($arrQuery);
			$arrQuery = array();
			for ($i=0; $i<count($arrId); $i++) {
				$objResult = $objDatabase->Execute("SELECT content,
									  title,
									  metadesc,
									  metakeys,
									  metarobots,
									  redirect,
									  expertmode
								 FROM ".DBPREFIX."content
								WHERE id=".intval($arrId[$i]['old']));
				if ($objResult !== false && $objResult->RecordCount()>0) {
					array_push($arrQuery,"INSERT INTO ".DBPREFIX."content (id,content,title,metadesc,metakeys,metarobots,redirect,expertmode)
					VALUES(
					'".intval($arrId[$i]['new'])."',
					'".addslashes($objResult->fields["content"])."', 
					'".addslashes($objResult->fields["title"])."',  
					'".addslashes($objResult->fields["metadesc"])."',  
					'".addslashes($objResult->fields["metakeys"])."', 
					'".addslashes($objResult->fields["metarobots"])."', 
					'".addslashes($objResult->fields["redirect"])."', 
					'".addslashes($objResult->fields["expertmode"])."'
					)
					");
				}
			}
			
			for ($i=0; $i<count($arrQuery); $i++){
				$objDatabase->Execute($arrQuery[$i]);
			}
			unset($arrQuery);	
			$objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."content_navigation");
			$objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."content");
		}
	}
	
	/**
    * Deletes all global site content
    *
    * @global object $objDatabase
    * @global array  $_CORELANG                                                                      
    */
	function _deleteAll($langId=0)
	{
		global $objDatabase, $_CORELANG, $objLanguage;
		
		if (isset($_GET['contentId']) && intval($_GET['contentId'])!=0) {
			$langId = intval($_GET['contentId']);
		} 
		if (intval($langId) != 0) {	
			// the default language site cannot be deleted
			if ($objLanguage->getLanguageParameter($langId, "is_default")=="true") {
				$this->statusMessage= $_CORELANG['TXT_STANDARD_SITE_NOT_DELETED'];
			} else {
				$arrQuery = array();
				$objResult = $objDatabase->Execute("SELECT catid FROM ".DBPREFIX."content_navigation WHERE lang=".intval($langId));
				if ($objResult !== false) {
					while (!$objResult->EOF) {
						array_push($arrQuery, "DELETE FROM ".DBPREFIX."content WHERE id=".intval($objResult->fields['catid']));
						$objResult->MoveNext();
					}
				}
				for ($i=0; $i<count($arrQuery); $i++) {
					$objDatabase->Execute($arrQuery[$i]);
				}
				unset($arrQuery);
				$objDatabase->Execute("DELETE FROM ".DBPREFIX."content_navigation WHERE lang=".intval($langId));
			}
		}
	}   
    
    /**
    * @access private
    * @return array
    * @param string groupType
    * @desc gets all frontend groups as an array
    */   
	function _getAllGroups($groupType="frontend")
	{
		$objDb = getDatabaseObject($this->statusMessage, true);
	    
        if ($groupType!="frontend") {
        	$groupType="backend";
        }
        	        
	    $arrGroups=array();	    
		$objResult = $objDb->Execute("SELECT group_id, group_name FROM ".DBPREFIX."access_user_groups WHERE type='".$groupType."'");
		if ($objResult !== false) {
	    	while (!$objResult->EOF) {
	    		$arrGroups[$objResult->fields['group_id']]=$objResult->fields['group_name'];
	    		$objResult->MoveNext();
	    	}
		}
    	return $arrGroups;					 				
	}
    
    /**
    * Show sitemap
    *
    * @version   1.0        initial version 
    * @global    object     $objDatabase
    * @global    array      $_GET['act']                                                                    
    */
    function contentOverview()
    {
    	global $objDatabase, $objTemplate;
    	    	        
	    $this->pageTitle = $_CORELANG['TXT_CONTENT_MANAGER']; 
        
		if ($_GET['act'] == "mod") {
			foreach ($_POST['catid'] as $value) {
				$displayorder_old = intval($_POST['displayorder_old'][$value]);
				$displayorder_new = intval($_POST['displayorder_new'][$value]);
				if ($displayorder_old != $displayorder_new) {
					$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation 
					                          SET displayorder=".$displayorder_new."
					                        WHERE catid=".intval($value));
				}
			}	
		}		
		$objNavbar = &new ContentSitemap(0);
		$objTemplate->setVariable('ADMIN_CONTENT', $objNavbar->getSiteMap());
		//$objTemplate->addBlock('ADMIN_CONTENT', 'siteMap', $objNavbar->getSiteMap());
    } 
    
    /**
    * Create new page
    *
    * @global    object     $objDatabase                                                                   
    */
    function showNewPage()
    {
	    global $objDatabase, $_CORELANG, $objTemplate;
	    
	    // init variables
	    $contenthtml="";
	    $pageId = "";
	    $tablestatus="none";
		$existingFrontendGroups = "";
		$existingBackendGroups = "";
		
		
	    $objTemplate->addBlockfile('ADMIN_CONTENT', 'content_editor', 'content_editor.html');
	    $this->pageTitle = $_CORELANG['TXT_NEW_PAGE'];
				
		if (isset($_GET['pageId']) & !empty($_GET['pageId'])) {
			$pageId = intval($_GET['pageId']);
				
			$objResult = $objDatabase->SelectLimit("SELECT content,
			                   metadesc, 
			                   metarobots, 
			                   title, 
			                   metakeys,
			                   css_name 
			              FROM ".DBPREFIX."content 
			             WHERE id = ".$pageId, 1);
			if ($objResult !== false && $objResult->RecordCount()>0) {
				$contenthtml= stripslashes($objResult->fields['content']);
				$contenthtml = preg_replace('/\{([A-Z0-9_]*?)\}/', '[[\\1]]' ,$contenthtml);		
				
				$objTemplate->setVariable(array(
					'CONTENT_HTML'	 => get_wysiwyg_editor('html', $contenthtml, 'active'),
					'CONTENT_DESC'   => $objResult->fields['contentdesc'],
					'CONTENT_META_TITLE'  => $objResult->fields['contenttitle'],
					'CONTENT_KEY'  	 => $objResult->fields['contentkey'],
					'CONTENT_CSS_NAME'  => $objResult->fields['css_name'],
				));
			}
			
			$objResult = $objDatabase->SelectLimit("SELECT module, 
			                   startdate, 
			                   enddate, 
			                   displaystatus,
			                   themes_id
			              FROM ".DBPREFIX."content_navigation 
			             WHERE catid = ".$pageId, 1);
			if ($objResult !== false && $objResult->RecordCount()>0) {
				$moduleId = $objResult->fields['module'];
				$startDate = $objResult->fields['startdate'];
				$endDate = $objResult->fields['enddate'];
				$displaystatus = "";
				$themesId = $objResult->fields['themes_id'];
				
				if ($objResult->fields['displaystatus'] == "on" ) { 
					$displaystatus = "checked";
				}

				$robotstatus = ($objResult->fields['metarobots'] == "index") ? "checked" : "";			
				
				$objTemplate->setVariable(array(
					'CONTENT_MODULE_MENU'              => $this->_getModuleMenu($moduleId),
					'CONTENT_STARTDATE'	               => $startDate,
					'CONTENT_ENDDATE'                  => $endDate,
					'CONTENT_DISPLAYSTATUS'            => $displaystatus,
					'CONTENT_TABLE_STYLE'              => $tablestatus,
					'CONTENT_ROBOTS'                   => $robotstatus,
					'CONTENT_THEMES_MENU'              => $this->_getThemesMenu($themesId)
				));	
			}																							
		} else {
			$arrAssignedFrontendGroups=$this->_getAssignedGroups($groupType="frontend");
			$objTemplate->setVariable(array(
				'CONTENT_HTML'	                   => get_wysiwyg_editor('html', $contenthtml, 'active'),
				'CONTENT_MODULE_MENU'              => $this->_getModuleMenu($selectedOption=""),	
				'CONTENT_DATE'	                   => date("Y-m-d"),
				'CONTENT_TABLE_STYLE'              => $tablestatus
			));
		}
		
		// Frontend Groups
    	foreach ($this->arrAllFrontendGroups as $id => $name) {
    		$existingFrontendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
    	}  
    	
		// Backend Groups
    	foreach ($this->arrAllBackendGroups as $id => $name) {
    		$existingBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
    	}    	
    		

		$objTemplate->setVariable(array(
		    'TXT_TARGET'               => $_CORELANG['TXT_TARGET'],
		    'TXT_MORE_OPTIONS'         => $_CORELANG['TXT_MORE_OPTIONS'],		    
		    'TXT_BASIC_DATA'           => $_CORELANG['TXT_BASIC_DATA'], 
		    'TXT_FRONTEND_PERMISSION'  => $_CORELANG['TXT_FRONTEND_PERMISSION'],
		    'TXT_RELATEDNESS'          => $_CORELANG['TXT_BACKEND_RELATEDNESS'],
		    'TXT_PAGE_NAME'            => $_CORELANG['TXT_PAGE_NAME'],
		    'TXT_MENU_NAME'            => $_CORELANG['TXT_MENU_NAME'],
		    'TXT_NEW_CATEGORY'         => $_CORELANG['TXT_NEW_CATEGORY'],
		    'TXT_ACTIVE'               => $_CORELANG['TXT_ACTIVE'],
		    'TXT_META_INFORMATIONS'    => $_CORELANG['TXT_META_INFORMATIONS'],
		    'TXT_META_TITLE'           => $_CORELANG['TXT_META_TITLE'],
		    'TXT_META_DESCRIPTION'     => $_CORELANG['TXT_META_DESCRIPTION'],
		    'TXT_META_KEYWORD'         => $_CORELANG['TXT_META_KEYWORD'],
		    'TXT_META_ROBOTS'          => $_CORELANG['TXT_META_ROBOTS'],		    
		    'TXT_CONTENT'              => $_CORELANG['TXT_CONTENT'],
		    'TXT_GENERAL_OPTIONS'      => $_CORELANG['TXT_GENERAL_OPTIONS'],
		    'TXT_START_DATE'           => $_CORELANG['TXT_START_DATE'],
		    'TXT_END_DATE'             => $_CORELANG['TXT_END_DATE'],
		    'TXT_EXPERT_MODE'          => $_CORELANG['TXT_EXPERT_MODE'],		    
		    'TXT_MODULE'               => $_CORELANG['TXT_MODULE'],
		    'TXT_NO_MODULE'            => $_CORELANG['TXT_NO_MODULE'],
		    'TXT_REDIRECT'             => $_CORELANG['TXT_REDIRECT'],
		    'TXT_NO_REDIRECT'          => "",
		    'TXT_SOURCE_MODE'          => $_CORELANG['TXT_SOURCE_MODE'],
		    'TXT_THEMES'               => $_CORELANG['TXT_THEMES'],
		    'TXT_STORE'                => $_CORELANG['TXT_STORE'],	
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_PROTECTION'           => $_CORELANG['TXT_PROTECTION'],	    
		    'TXT_PROTECTION_CHANGE'    => $_CORELANG['TXT_PROTECTION_CHANGE'],
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_GROUPS'               => $_CORELANG['TXT_GROUPS'],
		    'TXT_GROUPS_DEST'          => $_CORELANG['TXT_GROUPS_DEST'],
		    'TXT_SELECT_ALL'           => $_CORELANG['TXT_SELECT_ALL'],
		    'TXT_DESELECT_ALL'         => $_CORELANG['TXT_DESELECT_ALL'],
		    'TXT_ACCEPT_CHANGES'       => $_CORELANG['TXT_ACCEPT_CHANGES'],
		    'TXT_PUBLIC_PAGE'          => $_CORELANG['TXT_PUBLIC_PAGE'],
		    'TXT_BACKEND_RELEASE'      => $_CORELANG['TXT_BACKEND_RELEASE'],
		    'TXT_LIMIT_GROUP_RIGHTS'   => $_CORELANG['TXT_LIMIT_GROUP_RIGHTS'],
		    'TXT_TARGET_BLANK'         => $_CORELANG['TXT_TARGET_BLANK'],
		    'TXT_TARGET_TOP'           => $_CORELANG['TXT_TARGET_TOP'],
		    'TXT_TARGET_PARENT'        => $_CORELANG['TXT_TARGET_PARENT'],
		    'TXT_TARGET_SELF'          => $_CORELANG['TXT_TARGET_SELF'],
		    'TXT_OPTIONAL_CSS_NAME'    => $_CORELANG['TXT_OPTIONAL_CSS_NAME']
		));		
		
		$objTemplate->setVariable(array(
			'CONTENT_ACTION'                   => "add",
			'CONTENT_TOP_TITLE'                => $_CORELANG['TXT_NEW_PAGE'],
			'CONTENT_DISPLAYSTATUS'            => "checked",
			'CONTENT_CAT_MENU'                 => $this->getPageMenu(),
			'CONTENT_FORM_ACTION'              => "add",
			'CONTENT_ROBOTS'                   => "checked",
			'CONTENT_THEMES_MENU'              => $this->_getThemesMenu(),		
			'CONTENT_EXISTING_GROUPS'          => $existingFrontendGroups,
			//'CONTENT_ASSIGNED_GROUPS'          => "",
			'CONTENT_PROTECTION_INACTIVE'      => "checked",
			'CONTENT_PROTECTION_ACTIVE'        => "",
			'CONTENT_PROTECTION_DISPLAY'       => "none",
			'CONTENT_CONTROL_BACKEND_INACTIVE' => "checked",
			'CONTENT_CONTROL_BACKEND_ACTIVE'   => "",
			'CONTENT_CONTROL_BACKEND_DISPLAY'  => "none",
			'CONTENT_EXISTING_BACKEND_GROUPS'  => $existingBackendGroups,
			'CONTENT_ASSIGNED_BACKEND_GROUPS'  => ""
		));
    }
    
    /**
    * @access private
    * @return string
    * @param pageId int
    * @desc ckecks if the page is protected (returns "checked") or not.
    */   
	function _getPageProtectionStatus($pageId)
	{
		$objDb = getDatabaseObject($this->statusMessage, true);
		
		$objResult = $objDb->SelectLimit("SELECT protected FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId, 1);
		if ($objResult !== false && $objResult->RecordCount()>0 && isset($objResult->fields['protected']) && $objResult->fields['protected']) {
			return "checked";
		} else {
		    return "";
		}
	}
	
    /**
    * @access private
    * @return array
    * @param groupType string    
    * @param pageId int (optional)
    * @desc gets all frontend or backend groups ( id,name ) from this page
    */   
	function _getAssignedGroups($groupType, $pageId=0)
	{
		global $objDatabase;
		$arrAssignedGroups = array();
		
		if ($groupType != 'backend') {
			$groupType = 'frontend';
		}
		
		if (intval($pageId) != 0) {
			$objResult = $objDatabase->Execute("SELECT rights.group_id
												FROM ".DBPREFIX."content_navigation AS navigation,
														".DBPREFIX."access_group_dynamic_ids AS rights
												WHERE navigation.catid=".intval($pageId)."
												AND navigation.".$groupType."_access_id=rights.access_id");
			if ($objResult !== false) {
				while (!$objResult->EOF) {
					array_push($arrAssignedGroups, $objResult->fields['group_id']);
					$objResult->MoveNext();
				}
			}
		}
		return $arrAssignedGroups;
	}
    
    /**
    * Content editing
    *
    * This method manages all aspects of editing of content
    *        
    * @global  object  $objDatabase 
    * @global  array  $_CORELANG
    * @global  object  $objTemplate    
    * @global  object  $objPerm       
    */
	function showEditPage($pageId = '')
	{ 
		global $objDatabase, $_CORELANG, $objTemplate, $objPerm;
		
		if (empty($pageId)) {
			$pageId = intval($_REQUEST['pageId']);
		}
		
		$objResult = $objDatabase->Execute("SELECT backend_access_id FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId." AND backend_access_id!=0");
		if ($objResult !== false) {
			if ($objResult->RecordCount() == 1 && !$objPerm->checkAccess($objResult->fields['backend_access_id'], 'dynamic')) {
				header('Location: index.php?cmd=noaccess');
				exit;
			};
		} else {
			header('Location: index.php?cmd=noaccess');
			exit;
		}
		
		$objTemplate->addBlockfile('ADMIN_CONTENT', 'content_editor', 'content_editor.html');
	    $this->pageTitle = $_CORELANG['txtEditPage'];

		$objTemplate->setVariable(array(
		    'TXT_TARGET'               => $_CORELANG['TXT_TARGET'],
		    'TXT_MORE_OPTIONS'         => $_CORELANG['TXT_MORE_OPTIONS'],		    
		    'TXT_BASIC_DATA'           => $_CORELANG['TXT_BASIC_DATA'], 
		    'TXT_FRONTEND_PERMISSION'  => $_CORELANG['TXT_FRONTEND_PERMISSION'],
		    'TXT_RELATEDNESS'          => $_CORELANG['TXT_BACKEND_RELATEDNESS'],
		    'TXT_PAGE_NAME'            => $_CORELANG['TXT_PAGE_NAME'],
		    'TXT_MENU_NAME'            => $_CORELANG['TXT_MENU_NAME'],
		    'TXT_NEW_CATEGORY'         => $_CORELANG['TXT_NEW_CATEGORY'],
		    'TXT_ACTIVE'               => $_CORELANG['TXT_ACTIVE'],
		    'TXT_META_INFORMATIONS'    => $_CORELANG['TXT_META_INFORMATIONS'],
		    'TXT_META_TITLE'           => $_CORELANG['TXT_META_TITLE'],
		    'TXT_META_DESCRIPTION'     => $_CORELANG['TXT_META_DESCRIPTION'],
		    'TXT_META_KEYWORD'         => $_CORELANG['TXT_META_KEYWORD'],
		    'TXT_META_ROBOTS'          => $_CORELANG['TXT_META_ROBOTS'],		    
		    'TXT_CONTENT'              => $_CORELANG['TXT_CONTENT'],
		    'TXT_GENERAL_OPTIONS'      => $_CORELANG['TXT_GENERAL_OPTIONS'],
		    'TXT_START_DATE'           => $_CORELANG['TXT_START_DATE'],
		    'TXT_END_DATE'             => $_CORELANG['TXT_END_DATE'],
		    'TXT_EXPERT_MODE'          => $_CORELANG['TXT_EXPERT_MODE'],		    
		    'TXT_MODULE'               => $_CORELANG['TXT_MODULE'],
		    'TXT_NO_MODULE'            => $_CORELANG['TXT_NO_MODULE'],
		    'TXT_REDIRECT'             => $_CORELANG['TXT_REDIRECT'],
		    'TXT_NO_REDIRECT'          => "",
		    'TXT_SOURCE_MODE'          => $_CORELANG['TXT_SOURCE_MODE'],
		    'TXT_THEMES'               => $_CORELANG['TXT_THEMES'],
		    'TXT_STORE'                => $_CORELANG['TXT_STORE'],	
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_PROTECTION'           => $_CORELANG['TXT_PROTECTION'],	    
		    'TXT_PROTECTION_CHANGE'    => $_CORELANG['TXT_PROTECTION_CHANGE'],
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_GROUPS'               => $_CORELANG['TXT_GROUPS'],
		    'TXT_GROUPS_DEST'          => $_CORELANG['TXT_GROUPS_DEST'],
		    'TXT_SELECT_ALL'           => $_CORELANG['TXT_SELECT_ALL'],
		    'TXT_DESELECT_ALL'         => $_CORELANG['TXT_DESELECT_ALL'],
		    'TXT_ACCEPT_CHANGES'       => $_CORELANG['TXT_ACCEPT_CHANGES'],
		    'TXT_PUBLIC_PAGE'          => $_CORELANG['TXT_PUBLIC_PAGE'],
		    'TXT_BACKEND_RELEASE'      => $_CORELANG['TXT_BACKEND_RELEASE'],
		    'TXT_LIMIT_GROUP_RIGHTS'   => $_CORELANG['TXT_LIMIT_GROUP_RIGHTS'],	
		    'TXT_TARGET_BLANK'         => $_CORELANG['TXT_TARGET_BLANK'],
		    'TXT_TARGET_TOP'           => $_CORELANG['TXT_TARGET_TOP'],
		    'TXT_TARGET_PARENT'        => $_CORELANG['TXT_TARGET_PARENT'],
		    'TXT_TARGET_SELF'          => $_CORELANG['TXT_TARGET_SELF'],
		    'TXT_OPTIONAL_CSS_NAME'    => $_CORELANG['TXT_OPTIONAL_CSS_NAME']
		));
		
		if (!empty($pageId)) {
			$objResult = $objDatabase->SelectLimit("SELECT * 
			              FROM ".DBPREFIX."content 
			             WHERE id =".$pageId, 1);
			
			if ($objResult !== false && $objResult->RecordCount()>0) {
				$contenthtml = stripslashes($objResult->fields['content']);
				$contenthtml = preg_replace('/\{([A-Z0-9_]*?)\}/', '[[\\1]]' ,$contenthtml);
												
				if ($objResult->fields['expertmode'] == "y" ) {
					$expertmodeValue = "checked";
					$contenthtml = htmlspecialchars($contenthtml);
                    $ed = get_wysiwyg_editor('html',$contenthtml, 'html');					
				} else {
					$expertmodeValue = "";
					$ed = get_wysiwyg_editor('html',$contenthtml,'active');					

				}
				$robots = ($objResult->fields['metarobots'] == "index") ? "checked" : "";													
					
				$objTemplate->setVariable(array(
					'CONTENT_FORM_ACTION'      => "update",
					'CONTENT_TOP_TITLE'	       => $_CORELANG['TXT_EDIT_PAGE'],
					'CONTENT_CATID'            => $pageId,
					'CONTENT_HTML'	           => $ed,
					'CONTENT_DESC'	           => strip_tags(stripslashes($objResult->fields['metadesc'])),
					'CONTENT_META_TITLE'	   => strip_tags(stripslashes($objResult->fields['title'])),
					'CONTENT_KEY'	           => strip_tags(stripslashes($objResult->fields['metakeys'])),
					'CONTENT_CSS_NAME'	       => strip_tags(stripslashes($objResult->fields['css_name'])),					
					'CONTENT_ROBOTS'	       => $robots,
					'CONTENT_SHOW_EXPERTMODE'  => $expertmodeValue
				));
				unset($ed);
				$redirect = $objResult->fields['redirect'];
			}
			$objResult = $objDatabase->SelectLimit("SELECT module, 
			                   lang, 
			                   startdate, 
			                   enddate, 
			                   displaystatus, 
			                   catname, 
			                   catid, 
			                   target,
			                   cmd, 
			                   protected,
			                   themes_id 
			              FROM ".DBPREFIX."content_navigation 
			             WHERE catid = ".$pageId, 1);
			
			if ($objResult !== false && $objResult->RecordCount()>0) {
				$displaystatus = "";
				$moduleId = $objResult->fields['module'];
				$startDate = $objResult->fields['startdate'];
				$endDate = $objResult->fields['enddate'];
				$cmd = $objResult->fields['cmd'];
				$catname = htmlspecialchars(stripslashes($objResult->fields['catname']));
				$themesId = $objResult->fields['themes_id'];
				
				if ($objResult->fields['displaystatus'] == "on" ) { 
					$displaystatus = "checked";
				}
				$target = $objResult->fields['target'];
				//$target = "xyz";								
					
				$objTemplate->setVariable(array(
					'CONTENT_MENU_NAME'       => $catname,
					'CONTENT_CAT_MENU'	      => $this->getPageMenu($objResult->fields['catid']),
					'CONTENT_TARGET'          => $target,				
					'CONTENT_SHOW_CMD'        => $cmd,
					'CONTENT_MODULE_MENU'     => $this->_getModuleMenu($moduleId),
					'CONTENT_DISPLAYSTATUS'   => $displaystatus,	
					'CONTENT_STARTDATE'	      => $startDate,
					'CONTENT_CATID'           => $pageId,
					'CONTENT_ENDDATE'	      => $endDate,					
					'CONTENT_THEMES_MENU'     => $this->_getThemesMenu($themesId)
				));						
			}	
			
			// Frontend Groups
			////////////////////////////
			$arrAssignedFrontendGroups=$this->_getAssignedGroups($groupType="frontend",$pageId);
	    	foreach ($this->arrAllFrontendGroups as $id => $name) {
	    		if (in_array($id, $arrAssignedFrontendGroups)) {
	    		    $assignedGroups.="<option value=\"".$id."\">".$name."</option>\n";
	    		} else {
	    		    $existingGroups.="<option value=\"".$id."\">".$name."</option>\n";	
	    		}
	    	}
	    	
	    	$activeProtectionStatus = $this->_getPageProtectionStatus($pageId);
	    	if ($activeProtectionStatus=="checked") {
	    		$inactiveProtectionStatus = "";
	    		$displayStatus = "block";
	    	} else {
	    	    $inactiveProtectionStatus = "checked";
	    	    $displayStatus = "none";
	    	}

			// Backend Groups
			////////////////////////////
			$arrAssignedBackendGroups=$this->_getAssignedGroups($groupType="backend",$pageId);
			$_backendPermissions = false;
	    	foreach ($this->arrAllBackendGroups as $id => $name) {
	    		if (in_array($id, $arrAssignedBackendGroups)) {
	    		    $assignedBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";
	    		    $_backendPermissions = true;
	    		} else {
	    		    $existingBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
	    		}
	    	}
	    	
	    	if ($_backendPermissions) {
	    		$activeBackendStatus = "checked";
	    		$inactiveBackendStatus = "";
	    		$displayBackendStatus = "block";
	    	} else {
	    	    $inactiveBackendStatus = "checked";
	    	    $activeBackendStatus = "";
	    	    $displayBackendStatus = "none";
	    	}	    	   		
	    	
			$objTemplate->setVariable(array(
			    //// frontend
			    'CONTENT_EXISTING_GROUPS'     => $existingGroups,
			    'CONTENT_ASSIGNED_GROUPS'     => $assignedGroups,	 
				'CONTENT_PROTECTION_ACTIVE'   => $activeProtectionStatus,
				'CONTENT_PROTECTION_INACTIVE' => $inactiveProtectionStatus,	
				'CONTENT_PROTECTION_DISPLAY'  => $displayStatus,					
				//// backend
			    'CONTENT_EXISTING_BACKEND_GROUPS'  => $existingBackendGroups,
			    'CONTENT_ASSIGNED_BACKEND_GROUPS'  => $assignedBackendGroups,	 
				'CONTENT_CONTROL_BACKEND_ACTIVE'   => $activeBackendStatus,
				'CONTENT_CONTROL_BACKEND_INACTIVE' => $inactiveBackendStatus,	
				'CONTENT_CONTROL_BACKEND_DISPLAY'  => $displayBackendStatus
			));			
		}
		
		$objTemplate->setVariable(array(
			'TXT_NO_REDIRECT'        => $redirect,
			'CONTENT_CATID'          => $pageId
		));
	}
	
	/**
    * Update page content
    *                                                                    
    */
	function updatePage()
	{
		global $objDatabase, $_CORELANG;
		
		$expertmode = "n";
		if ($_POST['expertmode']== "y") { 
			$expertmode = "y"; 
		}
		$displaystatus = "off";
		if ($_POST['displaystatus']== "on") { 
			$displaystatus = "on"; 
		}
		$robotstatus = "noindex";
		if ($_POST['robots']== "index") { 
			$robotstatus = "index"; 
		}		
		$pageId = intval($_POST['pageId']);
		$catname = addslashes(strip_tags($_POST['newpage']));
		$contenthtml = addslashes($_POST['html']);
		$contenthtml = preg_replace('/\[\[([A-Z0-9_]*?)\]\]/', '{\\1}' ,$contenthtml);	
		$contenttitle = addslashes(strip_tags($_POST['title']));
		$contentdesc = addslashes(strip_tags($_POST['desc']));
		$contentkey = addslashes(strip_tags($_POST['key']));
		$command = addslashes(strip_tags($_POST['command']));
		$parcat = intval($_POST['category']);
		$moduleId  = intval($_POST['selectmodule']);
		$themesId = intval($_POST['themesId']);
		$startdate = preg_replace('/[^0-]*/', '',$_POST['startdate']);
		$enddate = preg_replace('/[^0-]*/', '',$_POST['enddate']);
		$currentTime = time();
		$cssName = get_magic_quotes_gpc() ? strip_tags($_POST['cssName']) : addslashes(strip_tags($_POST['cssName']));
		$redirect = get_magic_quotes_gpc() ? strip_tags($this->checkRedirectUrl($_POST['redirect'])) : addslashes(strip_tags($this->checkRedirectUrl($_POST['redirect'])));
		$redirectTarget	= in_array($_POST['redirectTarget'], $this->_arrRedirectTargets) ? $_POST['redirectTarget'] : "";
		
		$contenthtml=$this->_getBodyContent($contenthtml);
		
		
		//$date=substr($_POST['startdate'],0,4)."-".substr($_POST['startdate'],5,2);
		
		/*
		if(!$this->_homeModuleCheck($moduleId, $_POST['command'], $_POST['pageId'])){
            $homeMessage=$this->statusMessage;
            $moduleId=intval($this->setModule);
            $command=$this->setCmd;
		}
		*/
		
		$objDatabase->Execute("UPDATE ".DBPREFIX."content 
		               SET id='".$pageId."', 
		                   content='".$contenthtml."',
		                   title='".$contenttitle."',
		                   metadesc='".$contentdesc."',
		                   metakeys='".$contentkey."',
		                   css_name='".$cssName."',
		                   metarobots='".$robotstatus."',
		                   redirect='".$redirect."',
		                   expertmode='".$expertmode."'
		             WHERE id=".$pageId);
		
		if ($parcat!=$pageId) {
			$objDatabase->Execute( "UPDATE ".DBPREFIX."content_navigation 
			                SET parcat='".$parcat."',
			                    catname='".$catname."',
			                    target='".$redirectTarget."',
			                    displaystatus='".$displaystatus."',
			                    username='".$_SESSION['auth']['username']."',
			                    changelog='".$currentTime."',
			                    cmd='".$command."',
			                    lang='".$this->langId."',
			                    module='".$moduleId."',
			                    startdate='".$startdate."',
			                    enddate='".$enddate."',
			                    themes_id='".$themesId."'
			              WHERE catid=".$pageId);
		} else {
		   $objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation 
		                  SET catname='".$catname."',
		                      target='".$redirectTarget."',
							  displaystatus='".$displaystatus."',
							  username='".$_SESSION['auth']['username']."',
							  changelog='".$currentTime."',
							  cmd='".$command."',
							  lang='".$this->langId."',
							  module='".$moduleId."',
							  startdate='".$startdate."',
							  enddate='".$enddate."',
		   			          themes_id='".$themesId."'
		                WHERE catid=".$pageId);
		}							

		if (isset($_POST['themesRecursive']) && !empty($_POST['themesRecursive'])) {														
			$objNavbar = &new ContentSitemap(0);
			$catidarray = $objNavbar->getCurrentSonArray($pageId);			
		
			foreach ($catidarray as $value) {				
				$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET themes_id='".$themesId."' WHERE catid=".$value);
				$objDatabase->Execute("UPDATE ".DBPREFIX."content SET css_name='".$cssName."' WHERE id=".$value);
			}	
		}
		$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL']; 
		$protect = (empty($_POST['protection']) ? false : true);
		$this->_setPageProtection($pageId, $parcat, $protect, $_POST['assignedGroups'], 'frontend', $_POST['recursive']);
		$protect = (empty($_POST['backendPermission']) ? false : true);
		$this->_setPageProtection($pageId, $parcat, $protect, $_POST['assignedBackendGroups'], 'backend', $_POST['backendInherit']);
		$this->statusMessage .= $homeMessage;
	}
	
    /**
    * Adds a new page
    *
    * @global    object     $objDatabase                                                                   
    */
	function addPage()
	{
		global $objDatabase, $_CORELANG;
		
		$parcat = !empty($_POST['category']) ? intval($_POST['category']) : 0;		
		$displaystatus = ( $_POST['displaystatus'] == "on" ) ? "on" : "off";		
		$expertmode = ( $_POST['expertmode'] == "y" ) ? "y" : "n";		
		$robotstatus = ( $_POST['robots'] == "index" ) ? "index" : "noindex";
				
		$catname = 	get_magic_quotes_gpc() ? strip_tags($_POST['newpage']) : strip_tags(addslashes($_POST['newpage']));
		$section = 	get_magic_quotes_gpc() ? strip_tags($_POST['section']) : strip_tags(addslashes($_POST['section']));
		$command = 	get_magic_quotes_gpc() ? strip_tags($_POST['command']) : strip_tags(addslashes($_POST['command']));
		$contenthtml= get_magic_quotes_gpc() ? $_POST['html'] : addslashes($_POST['html']);
		$contenthtml = preg_replace('/\[\[([A-Z0-9_]*?)\]\]/', '{\\1}' ,$contenthtml);	
		$contenttitle = 	get_magic_quotes_gpc() ? htmlspecialchars($_POST['title']) : htmlspecialchars(addslashes($_POST['title']));
		$contentdesc = 	get_magic_quotes_gpc() ? strip_tags($_POST['desc']) : strip_tags(addslashes($_POST['desc']));
		$contentkey = 	get_magic_quotes_gpc() ? strip_tags($_POST['key']) : strip_tags(addslashes($_POST['key']));		
			
		$redirect = get_magic_quotes_gpc() ? strip_tags($this->checkRedirectUrl($_POST['redirect'])) : addslashes(strip_tags($this->checkRedirectUrl($_POST['redirect'])));
		$redirectTarget	= in_array($_POST['redirectTarget'], $this->_arrRedirectTargets) ? $_POST['redirectTarget'] : "";
		$cssName = get_magic_quotes_gpc() ? strip_tags($_POST['cssName']) : addslashes(strip_tags($_POST['cssName']));
		$modul = intval($_POST['selectmodule']);
		$startdate = preg_replace('/[^0-]*/', '',$_POST['startdate']);
		$enddate = preg_replace('/[^0-]*/', '',$_POST['enddate']);
		$themesId = intval($_POST['themesId']);
		$currentTime = time();
		
		if (!$this->_homeModuleCheck($modul,$command,'')==true) {
            $homemessage=$this->statusMessage;;
            $modul=intval($this->setModule);
            $command=$this->setCmd;
		}

		// Check if Expertmode is set for modules
		// module 15 is the home module (buggy test)
		if ($modul!=0 && $modul!=15) {
			$expertmode="y";
		}	
			
		$protected=0;	
		$objResult = $objDatabase->Execute("SELECT protected, themes_id FROM ".DBPREFIX."content_navigation WHERE catid=".$parcat);
		if ($objResult !== false && $objResult->RecordCount()>0) {
			if ($objResult->fields['protected']) {
				$protected=1;
			}
			if ($themesId == 0) {
				$themesId = $objResult->fields['themes_id'];
			}
		}					
				
		$contentredirect= $this->checkRedirectUrl($redirect);	
		$contenthtml=$this->_getBodyContent($contenthtml);
  		$q1 = "INSERT INTO ".DBPREFIX."content_navigation (catid, 
											  		parcat, 
											  		catname,
  		                                            target,
											  		displayorder, 
											  		displaystatus, 
											  		username, 
											  		changelog, 
											  		cmd, 
											  		lang,
											  		module,
											  		startdate,
											  		enddate,
  													protected,
  		                                            themes_id)
									         VALUES('',
											  		".$parcat.",
											  		'".$catname."',
  		                                            '".$redirectTarget."', 
											  		'1',
											  		'".$displaystatus."',
											  		'".$_SESSION['auth']['username']."',
											  		'".$currentTime."',
											  		'".$command."',
											  		'".$this->langId."',
											  		'".$modul."',
											  		'".$startdate."',
											  		'".$enddate."',
  		                                            '".$protected."',
  		                                            '".$themesId."')";
  		
  		
		$objDatabase->Execute($q1);
		$pageId = $objDatabase->Insert_ID();
		
		$q2 ="INSERT INTO ".DBPREFIX."content (id,
												content,
												title,
												metadesc,
												metakeys,
												css_name,
		                                        metarobots,
												redirect,
												expertmode)
										VALUES ($pageId,
												'".$contenthtml."',
												'".$contenttitle."',
												'".$contentdesc."',
												'".$contentkey."',
												'".$cssName."',
		                                        '$robotstatus',
												'$contentredirect', 
												'$expertmode')";
		
		if ($objDatabase->Execute($q2) !== false) {
			$this->statusMessage = $_CORELANG['TXT_DATA_RECORD_ADDED_SUCCESSFUL']; 
			$protect = (empty($_POST['protection']) ? false : true);
			$this->_setPageProtection($pageId, $parcat, $protect, $_POST['assignedGroups'], 'frontend', $_POST['recursive']);
			$protect = (empty($_POST['backendPermission']) ? false : true);
			$this->_setPageProtection($pageId, $parcat, $protect, $_POST['assignedBackendGroups'], 'backend', $_POST['backendInherit']);
			$this->statusMessage .= $homemessage;
		} else {
			$this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];
		}
		return $pageId;
	}
	
	/**
    * Delete page content
    *
    * @global    object     $objDatabase
    * @global    array      $_CORELANG[*]                                                                       
    */
	function deleteContent()
	{
		global $objDatabase, $_CORELANG;
		
		if (isset($_GET['pageId']) && !empty($_GET['pageId'])) {
			$pageId = intval($_GET['pageId']);
			
			$objResult = $objDatabase->Execute("SELECT parcat, 
			                   catid, 
			                   module 
			              FROM ".DBPREFIX."content_navigation 
			             WHERE parcat=".$pageId."
			                OR catid=".$pageId."
			          ORDER BY catid");
			
			if ($objResult !== false && $objResult->RecordCount()>0) {
                $moduleId = $objResult->fields['module'];
                // needed for recordcount
                while (!$objResult->EOF) {
                	$objResult->MoveNext();
                }
				if ($objResult->RecordCount()>1) {
					$this->statusMessage=$_CORELANG['TXT_PAGE_NOT_DELETED_DELETE_SUBCATEGORIES_FIRST']; 
				} else {
					if (in_array($moduleId, $this->_requiredModules)) {
					    $this->statusMessage=$_CORELANG['TXT_NOT_DELETE_REQUIRED_MODULES'];	
					} else {
						$q1 = "DELETE FROM ".DBPREFIX."content WHERE id=".$pageId;
						$q2 = "DELETE FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId;
						if ($objDatabase->Execute($q1) === false || $objDatabase->Execute($q2) === false) {
							$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR']; 
						} else {	
						     $this->statusMessage=$_CORELANG['TXT_DATA_RECORD_DELETED_SUCCESSFUL'];
						}
					}
				}                
			}
		}
	}
	
	/**
    * Add page to repository
    *
    * @global    object     $objDatabase
    * @global    array      $_CORELANG                                                                      
    */
	function addToRepository()
	{	
		global $objDatabase, $_CORELANG;
		
	    $pageId = intval($_GET['pageid']);
		if ($pageId != "" ) {		
		    $objNavbar= &new ContentSitemap(0);		    
			$catidarray=$objNavbar->getCurrentSonArray($pageId);	
			array_unshift ($catidarray,$pageId);		
			foreach ($catidarray as $value) {			
				$objResult = $objDatabase->Execute("SELECT * 
				              FROM ".DBPREFIX."content_navigation, 
				                   ".DBPREFIX."content 
				             WHERE id=catid 
				               AND catid=".$value);
				
				if ($objResult !== false && $objResult->RecordCount()>0) {
					$repository['displayorder'] = $objResult->fields['displayorder'];
					$repository['displaystatus'] = $objResult->fields['displaystatus'];
					$repository['cmd'] = $objResult->fields['cmd'];
					$repository['lang'] = $objResult->fields['lang'];
					$repository['content'] = $objResult->fields['content'];
					$repository['title'] = $objResult->fields['title'];
					$repository['expertmode'] = $objResult->fields['expertmode'];
					$repository['moduleid'] = intval($objResult->fields['module']);
					$repository['lang'] = intval($objResult->fields['lang']);
					$repository['username'] = $objResult->fields['username'];
					
					if ($paridarray[$objResult->fields['parcat']]) {
					    $repository['parid']= $paridarray[$objResult->fields['parcat']];
					} else {
						if (!$justonce) {
							$objDatabase->Execute("DELETE FROM ".DBPREFIX."module_repository WHERE moduleid='".$repository['moduleid']."'");
						}
						$justonce=true;
				        $repository['parid']= 0;				
					}
				}
				$query = "INSERT INTO ".DBPREFIX."module_repository SET
									displayorder ='".$repository['displayorder']."',
									displaystatus ='".$repository['displaystatus']."',
				                    username = '".addslashes($repository['username'])."',
									cmd = '".addslashes($repository['cmd'])."',
									content = '".addslashes($repository['content'])."',
									title = '".addslashes($repository['title'])."',
									expertmode ='".$repository['expertmode']."',
									moduleid ='".$repository['moduleid']."',
									lang ='".$repository['lang']."',	
									parid ='".$repository['parid']."'";

				if ($objDatabase->Execute($query) === false) {
					$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR']; 
				}
				
				$paridarray[$value] = $objDatabase->Insert_ID();
			}
			$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];			
		}
	}
	
	/**
    * string checkRedirectUrl($redirect)
    *
    * @param     string     redirect string
    * @return    string     checked redirect string                                                                              
    */
    function checkRedirectUrl($redirect)
    {
		if (!empty($redirect) AND strlen($redirect)>10) {
			if (!eregi("^(http://|https://|ftp://)", $redirect)) {
				$redirect = "http://" . $redirect;
			}
		} else {
			$redirect = "";
		}
		return $redirect; 
    }
    
	/**
    * Gets the search option menus string
    * 
    * @global    object     $objDatabase
    * @param     string     optional $selectedOption
    * @return    string     $modulesMenu                                                                              
    */
    function _getModuleMenu($selectedOption="")
    {
	    global $objDatabase;
	    $strMenu = "";	

	    $q = "SELECT * FROM ".DBPREFIX."modules WHERE 1 AND id<>0 ORDER BY id";
		$objResult = $objDatabase->Execute($q);
		if ($objResult !== false) {
			while (!$objResult->EOF) {
				$selected = ($selectedOption==$objResult->fields['id']) ? "selected" : "";
				$strMenu .="<option value=\"".$objResult->fields['id']."\" $selected>".$objResult->fields['name']."</option>\n"; 
				$objResult->MoveNext();
			}
		}
	    return $strMenu;
    }
	
    /**
    * Gets the body-content
    *
    * this function removes all the content outside the body tags
    *
    * @param     string     $fullContent      HTML-Content with more than BODY
    * @return    string     $content          HTML-Content between BODY-Tag                                                                
    */
    function _getBodyContent($fullContent)
    {
	    $res=false;
	    $posBody=0;
	    $posStartBodyContent=0;
	    $res=preg_match_all("/<body[^>]*>/i", $fullContent, $arrayMatches);
	    if ($res==true) {
            $bodyStartTag = $arrayMatches[0][0];
            // Position des Start-Tags holen
            $posBody = strpos($fullContent, $bodyStartTag, 0);
            // Beginn des Contents ohne Body-Tag berechnen 
            $posStartBodyContent = $posBody + strlen($bodyStartTag);
	    }
	    $posEndTag=strlen($fullContent);
	    $res=preg_match_all("/<\/body>/i",$fullContent, $arrayMatches);
	    if ($res==true) {
            $bodyEndTag=$arrayMatches[0][0];
            // Position des End-Tags holen
            $posEndTag = strpos($fullContent, $bodyEndTag, 0);
            // Content innerhalb der Body-Tags auslesen
	     }
	     $content = substr($fullContent, $posStartBodyContent, $posEndTag  - $posStartBodyContent);
         return $content;
    }
	
    
    
    
    function _homeModuleCheck($section,$cmd,$pageId)
    {
    	global $objDatabase, $_CORELANG;
    	$lang=$this->langId;
    	$section=intval($section);
    	
    	$objResult = $objDatabase->Execute("SELECT id FROM ".DBPREFIX."modules WHERE name='home'");
    	if ($objResult !== false && $objResult->RecordCount()>0) {
			$homeModuleId = intval($objResult->fields['id']);
    	} else {
    		$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];
    		return false;
    	}
    	
    	$objResult = $objDatabase->Execute("SELECT catid FROM ".DBPREFIX."content_navigation WHERE  lang=".$lang." AND module=".$homeModuleId);
    	if ($objResult !== false && $objResult->RecordCount()>0) {
    		$objResult = $objDatabase->Execute("SELECT m.name 
		                      FROM ".DBPREFIX."content_navigation AS n, 
		                           ".DBPREFIX."modules AS m 
		                     WHERE n.lang=".$lang."
		                       AND n.module=".$section."
		                       AND n.cmd='".$cmd."'
		                       AND n.module>0 
		                       AND n.catid<>'".$pageId."'");
		     
			if ($objResult !== false) {
				if ($objResult->RecordCount()>0) {
					$sectionName = $objResult->fields['m.name'];
					$this->statusMessage=$_CORELANG['TXT_PAGE_WITH_SAME_MODULE_EXIST']." ".$sectionName." ".$cmd;
					$this->setModule=$section;
					$this->setCmd=$cmd+1;
					return false;
				} else {
					return true;
				}
			} elseif ($section==$homeModuleId) {
                return true;
		    } else {
				$this->statusMessage=$_CORELANG['TXT_CREATE_HOME_MODULE'];
				$this->setModule=$homeModuleId;
				return false;
		    }
		}
	    $this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];
        return  false;
    }
	
	/*
	* Get dropdown menue
	*
	* Gets back a dropdown menu like  <option value='catid'>Catname</option>

    *
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function getPageMenu($selectedid=0)
	{
		global $objDatabase;
		
		$objResult = $objDatabase->Execute("SELECT catid, parcat, catname
											FROM ".DBPREFIX."content_navigation 
											WHERE lang=".$this->langId."
											ORDER BY parcat ASC, 
											         displayorder ASC");
		if ($objResult === false) {
			return "content::navigation() database error";
		}
		
		while (!$objResult->EOF) {
		    $this->_navtable[$objResult->fields['parcat']][$objResult->fields['catid']] = stripslashes($objResult->fields['catname']);
		    $objResult->MoveNext();
		}
		
		$result = $this->_getNavigationMenu($parcat=0, 0,$selectedid);
		return $result;
	}
	
	/*
	* Do navigation dropdown
	*
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function _getNavigationMenu($parcat=0,$level,$selectedid)
	{
		$result="";
		
		$list = $this->_navtable[$parcat];
		if (is_array($list)) {
			while (list($key,$val) = each($list)) {
				$output ="";
				$selected ="";
				if ($level!="0") {
					$count = $level*3;
					for ($i = 1; $i <= $count; $i++) {
						$output .=".";
					}
				}
				if ($selectedid==$key) {
					$selected= "selected";
				}
				$result.= "<option value='$key' $selected>$output$val</option>\n";
				if (isset($this->_navtable[$key])) {
					$result.= $this->_getNavigationMenu($key,$level+1,$selectedid);
				}
			}
		}
		return $result;
	}    
	
	/**
    * Change page protection
    *
    * @global    object     $objDatabase
    * @global    array      $_CORELANG[*]                                                                       
    */
	function changeProtection()
	{
		global $objDatabase, $_CORELANG;
		
		$this->pagetitle = $_CORELANG['TXT_CONTENT_MANAGER'];
		$loginModuleId = 18;
		
		if (!empty($_REQUEST['Id'])) {							
			$pageId = intval($_REQUEST['Id']);
			$objResult = $objDatabase->Execute("SELECT protected FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId);
			if ($objResult !== false && $objResult->RecordCount()>0) {
				$newprotected = ($objResult->fields["protected"]) ? 0:1;
				$objNavbar= &new ContentSitemap(0);
				$moduleId = intval($objResult->fields["protected"]);
				$catidarray=$objNavbar->getCurrentSonArray($pageId);
				$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET protected = ".$newprotected." WHERE catid=".$pageId);
				foreach ($catidarray as $value) {
					$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET protected = ".$newprotected." WHERE catid=".$value);
				}
				// Login Module must be unprotected!
				$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET protected=0 WHERE module=".$loginModuleId);
				
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			} else {					
				$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];   	
			}
		}
	}
	
	/**
    * Change page status
    *
    * @global    array      $_CORELANG                                                                       
    */
	function changeStatus()
	{
		global $objDatabase, $_CORELANG;

		if (isset($_REQUEST['pageId']) && !empty($_REQUEST['pageId'])) {							
			$currentTime = time();
			$pageId = intval($_REQUEST['pageId']);
			
			$objResult = $objDatabase->Execute("SELECT displaystatus FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId);
			if ($objResult !== false && $objResult->RecordCount()>0) {
				if ($objResult->fields['displaystatus']=='on') {
					$newstatus='off';
				} else {
					$newstatus='on';
				}
				
				$objNavbar= &new ContentSitemap(0);
				$catidarray=$objNavbar->getCurrentSonArray($pageId);

				$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation 
				                          SET displaystatus = '".$newstatus."',
				                              username='".$_SESSION['auth']['username']."',
				                              changelog='".$currentTime."'
				                        WHERE catid=".$pageId);
				
				foreach ($catidarray as $value) {
					$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET displaystatus = '".$newstatus."' WHERE catid=".$pageId);
				}
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			} else {					
				$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];   	
			}
		}
	}
	
	function _setPageProtection($pageId, $parentPageId, $protect, $arrGroups, $type, $recursive = false)
	{
		global $objDatabase, $_CONFIG;
		
		$rightId = 0;
		$pageIsProtected = false;
		$protectionString = "";
		$lastRightId = $_CONFIG['lastAccessId'];
		
		if (!is_array($arrGroups)) {
			$protect = false;
		}
		
		if (!$protect && $parentPageId != 0 && $parentPageId != $pageId) {
			$arrGroups = array();
			
			$objResult = $objDatabase->Execute("SELECT rights.group_id
											FROM ".DBPREFIX."access_group_dynamic_ids AS rights,
												 ".DBPREFIX."content_navigation AS navigation
											WHERE navigation.catid=".$parentPageId." AND rights.access_id=navigation.".$type."_access_id");
			if ($objResult !== false) {
				while (!$objResult->EOF) {
					array_push($arrGroups, $objResult->fields['group_id']);
					$objResult->MoveNext();
				}
			}
			
			if (count($arrGroups)>0) {
				$protect = true;
			}
		}
		
		if ($type == 'frontend') {
			$protectionString = "protected=".($protect ? "1" : "0").",";
		}
		
		if ($recursive) {
			$objNavbar = &new ContentSitemap(0);
			$arrSubPageIds = $objNavbar->getCurrentSonArray($pageId);
		}
		
		// get page protection info
		$objResult = $objDatabase->Execute("SELECT ".$type."_access_id AS access_id FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId);
		if ($objResult !== false) {
			if (!empty($objResult->fields['access_id'])) {
				$pageIsProtected = true;
				$rightId = $objResult->fields['access_id'];
			}
		}
		
		if ($protect) {
			if ($pageIsProtected) { // page was already protected, so update only the group permissions
				// remove old group permissions
				$objDatabase->Execute("DELETE FROM ".DBPREFIX."access_group_dynamic_ids WHERE access_id=".$rightId);
				
				// add new group permissions
				foreach ($arrGroups as $groupId) {
					$objDatabase->Execute("INSERT INTO ".DBPREFIX."access_group_dynamic_ids (`access_id`,`group_id`) VALUES (".$rightId.", ".intval($groupId).")");
				}
			} else { // the page wasn't protected, so protect the page and set the group permissions
				$lastRightId++;
				if ($objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET ".$protectionString." ".$type."_access_id=".$lastRightId." WHERE catid=".$pageId) !== false) {
					foreach ($arrGroups as $groupId) {
						$objDatabase->Execute("INSERT INTO ".DBPREFIX."access_group_dynamic_ids (`access_id`, `group_id`) VALUES (".$lastRightId.", ".intval($groupId).")");
					}
				} else {
					$lastRightId--;
				}
			}
			
			if ($recursive) {
				foreach ($arrSubPageIds as $subPageId) {
					$objResult = $objDatabase->Execute("SELECT ".$type."_access_id AS access_id FROM ".DBPREFIX."content_navigation WHERE catid=".$subPageId);
					if ($objResult !== false) {
						if (!empty($objResult->fields['access_id'])) { // page was already protected, so update only the group permissions
							$objDatabase->Execute("DELETE FROM ".DBPREFIX."access_group_dynamic_ids WHERE access_id=".$objResult->fields['access_id']);
							foreach ($arrGroups as $groupId) {
								$objDatabase->Execute("INSERT INTO ".DBPREFIX."access_group_dynamic_ids (`access_id`, `group_id`) VALUES (".$objResult->fields['access_id'].", ".intval($groupId).")");
							}
						} else { // the page wasn't protected, so protect the page and set the group permissions
							$lastRightId++;
							if ($objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET ".$protectionString." ".$type."_access_id=".$lastRightId." WHERE catid=".$subPageId) !== false) {
								foreach ($arrGroups as $groupId) {
									$objDatabase->Execute("INSERT INTO ".DBPREFIX."access_group_dynamic_ids (`access_id`, `group_id`) VALUES (".$lastRightId.", ".intval($groupId).")");
								}
							} else {
								$lastRightId--;
							}
						}
					} else {
						// the page $subPageId couldn't be protected
					}
				}
			}
		} else {
			// remove protection
			if ($pageIsProtected) {
				$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET ".$protectionString." ".$type."_access_id=NULL WHERE catid=".$pageId);
				$objDatabase->Execute("DELETE FROM ".DBPREFIX."access_group_dynamic_ids WHERE access_id=".$rightId);
			}
			
			if ($recursive) {
				// remove protection from sub pages
				foreach ($arrSubPageIds as $subPageId) {
					$objResult = $objDatabase->Execute("SELECT ".$type."_access_id AS access_id FROM ".DBPREFIX."content_navigation WHERE catid=".$subPageId);
					if ($objResult != false) {
						if (!empty($objResult->fields['access_id'])) {
							$objDatabase->Execute("UPDATE ".DBPREFIX."content_navigation SET ".$protectionString." ".$type."_access_id=NULL WHERE catid=".$subPageId);
							$objDatabase->Execute("DELETE FROM ".DBPREFIX."access_group_dynamic_ids WHERE access_id=".$objResult->fields['access_id']);
						}
					}
				}
			}
		}
		
		if ($lastRightId > $_CONFIG['lastAccessId']) {
			$_CONFIG['lastAccessId'] = $lastRightId;
			$objDatabase->Execute("UPDATE ".DBPREFIX."settings SET setvalue=".$lastRightId." WHERE setname='lastAccessId'");
		}
	}
	
	/*
	* Do navigation dropdown
	*
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $selectedid
    * @return   string   $result
    */		
	function _getThemesMenu($id=null)
	{
		global $objDatabase, $_CORELANG; 
		
		$themesId = intval($id);
                		
		$return = "<option value='0' selected>(".$_CORELANG['TXT_STANDARD'].")</option>\n";		
		$objResult = $objDatabase->Execute("SELECT id,themesname FROM ".DBPREFIX."skins ORDER BY id");
		if ($objResult !== false) {
			while (!$objResult->EOF) {
				$selected= ($objResult->fields['id']==$themesId) ? " selected" : "";						
				$return .="<option value='".$objResult->fields['id']."'$selected>".$objResult->fields['themesname']."</option>\n";
				$objResult->MoveNext();
			}
		}
		return $return;
	}	
}
?>
